@@ -3,6 +3,7 @@ use strict;
 use warnings;
 use parent qw/Class::Accessor::Fast/;
 use Carp ();
+use Plack::Util;
 use overload '&{}' => sub { shift->to_app(@_) }, fallback => 1;
 
 __PACKAGE__->mk_accessors(qw/app/);
@@ -29,6 +30,52 @@ sub to_app {
     return sub { $self->call(@_) };
 }
 
+sub response_cb {
+    my($self, $res, $cb) = @_;
+
+    my $body_filter = sub {
+        my($cb, $res) = @_;
+        my $filter_cb = $cb->($res);
+        # If response_cb returns a callback, treat it as a $body filter
+        if (defined $filter_cb && ref $filter_cb eq 'CODE') {
+            if (defined $res->[2]) {
+                my $body    = $res->[2];
+                my $getline = ref $body eq 'ARRAY' ? sub { shift @$body } : sub { $body->getline };
+                $res->[2] = Plack::Util::inline_object
+                    getline => sub { $filter_cb->($getline->()) },
+                    close => sub { $body->close if ref $body ne 'ARRAY' };
+            } else {
+                return $filter_cb;
+            }
+        }
+    };
+
+    if (ref $res eq 'ARRAY') {
+        $body_filter->($cb, $res);
+        return $res;
+    } elsif (ref $res eq 'CODE') {
+        return sub {
+            my $respond = shift;
+            $res->(sub {
+                my $res = shift;
+                my $filter_cb = $body_filter->($cb, $res);
+                if ($filter_cb) {
+                    my $writer = $respond->($res);
+                    if ($writer) {
+                        return Plack::Util::inline_object
+                            write => sub { $writer->write($filter_cb->(@_)) },
+                            close => sub { $writer->write($filter_cb->(undef)); $writer->close };
+                    }
+                } else {
+                    return $respond->($res);
+                }
+            });
+        };
+    }
+
+    return $res;
+}
+
 1;
 
 __END__
